package iot.sixiang.license.balance;

import iot.sixiang.license.entity.Server;
import iot.sixiang.license.service.ServerService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import javax.annotation.PostConstruct;
import java.security.NoSuchAlgorithmException;
import java.security.SecureRandom;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Component
@Slf4j
public class BalanceManager {
    @Autowired
    private ServerService serverService;

    private Map<String, Server> allServers = null;

    public BalanceManager() {
        allServers = new HashMap<String, Server>();
    }

    @PostConstruct
    public void init() {
        List<Server> servers = serverService.getServerList(0, 20);
        for (Server server : servers) {
            String serverIp = server.getServerIp();
            allServers.put(serverIp, server);
        }
    }

    public Server getBalanceServer() {
        int count = allServers.size();
        if (count == 0) {
            return null;
        } else {
            SecureRandom secureRandom = null;
            try {
                secureRandom = SecureRandom.getInstance("SHA1PRNG");
            } catch (NoSuchAlgorithmException e) {
                log.error("SecureRandom 不可用");
            }
            int index = 0;
            if (secureRandom != null) {
                index = secureRandom.nextInt(count);
            }
            List<Server> servers = new ArrayList<>(allServers.values());
            return servers.get(index);
        }
    }

}
